function [ret,x0,str,ts,xts]=findesat(t,x,u,flag);
%FINDESAT	is the M-file description of the SIMULINK system named FINDESAT.
%	The block-diagram can be displayed by typing: FINDESAT.
%
%	SYS=FINDESAT(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes FINDESAT to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling FINDESAT with a FLAG of zero:
%	[SIZES]=FINDESAT([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,50,1267,947])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    'temps_init_tmc')
set_param(sys,'Stop time',     '20000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '0.5')
set_param(sys,'Relative error','1e-4')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time algorithm','+1500')

add_block('built-in/Note',[sys,'/','NANOSATELLITE CASAA-SAT'])
set_param([sys,'/','NANOSATELLITE CASAA-SAT'],...
		'Font Name','Arial',...
		'Font Size',24,...
		'position',[620,5,625,10])

add_block('built-in/Note',[sys,'/','(Avec les quations TMC Garino-Guiziou )'])
set_param([sys,'/','(Avec les quations TMC Garino-Guiziou )'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[750,650,755,655])

add_block('built-in/Note',[sys,'/','6 variables=3 vitesses( 1  3)+3 angles(4  6)'])
set_param([sys,'/','6 variables=3 vitesses( 1  3)+3 angles(4  6)'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[395,650,400,655])

add_block('built-in/Note',[sys,'/',['Retour d''tat']])
set_param([sys,'/',['Retour d''tat']],...
		'position',[160,650,165,655])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[4,68,1272,965])

add_block('built-in/Note',[sys,'/','Subsystem2/REGULATION 2 MAGNECOUPLEURS + 1 ROUE TANGAGE'])
set_param([sys,'/','Subsystem2/REGULATION 2 MAGNECOUPLEURS + 1 ROUE TANGAGE'],...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[565,5,570,10])

add_block('built-in/Mux',[sys,'/','Subsystem2/Mux1'])
set_param([sys,'/','Subsystem2/Mux1'],...
		'inputs','3',...
		'position',[175,274,215,356])

add_block('built-in/Mux',[sys,'/','Subsystem2/Mux'])
set_param([sys,'/','Subsystem2/Mux'],...
		'inputs','2',...
		'position',[175,89,220,251])

add_block('built-in/Constant',[sys,'/','Subsystem2/Constant'])
set_param([sys,'/','Subsystem2/Constant'],...
		'hide name',0,...
		'Value','consigne_tangage',...
		'position',[130,525,240,545])

add_block('built-in/Sum',[sys,'/','Subsystem2/Sum2'])
set_param([sys,'/','Subsystem2/Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[275,515,305,590])

add_block('built-in/Demux',[sys,'/','Subsystem2/Demux4'])
set_param([sys,'/','Subsystem2/Demux4'],...
		'hide name',0,...
		'outputs','[3 1 1 1]',...
		'position',[40,70,85,230])

add_block('built-in/Note',[sys,'/','Subsystem2/Lacet'])
set_param([sys,'/','Subsystem2/Lacet'],...
		'position',[200,200,205,205])

add_block('built-in/Note',[sys,'/',['Subsystem2/Vitesses',13,'inutiles']])
set_param([sys,'/',['Subsystem2/Vitesses',13,'inutiles']],...
		'position',[125,65,130,70])

add_block('built-in/Note',[sys,'/','Subsystem2/Roulis'])
set_param([sys,'/','Subsystem2/Roulis'],...
		'position',[205,115,210,120])

add_block('built-in/Note',[sys,'/','Subsystem2/Tangage'])
set_param([sys,'/','Subsystem2/Tangage'],...
		'position',[115,145,120,150])

add_block('built-in/Note',[sys,'/','Subsystem2/Consigne-Angles'])
set_param([sys,'/','Subsystem2/Consigne-Angles'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[320,210,325,215])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[0,140,20,160])

add_block('built-in/Note',[sys,'/',['Subsystem2/Entre des angles',13,'roulis et lacet']])
set_param([sys,'/',['Subsystem2/Entre des angles',13,'roulis et lacet']],...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[325,30,330,35])

add_block('built-in/Note',[sys,'/',['Subsystem2/Roulis',13,'lacet']])
set_param([sys,'/',['Subsystem2/Roulis',13,'lacet']],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[520,90,525,95])

add_block('built-in/Note',[sys,'/','Subsystem2/B'])
set_param([sys,'/','Subsystem2/B'],...
		'position',[501,270,506,275])

add_block('built-in/Note',[sys,'/','Subsystem2/By'])
set_param([sys,'/','Subsystem2/By'],...
		'position',[555,290,560,295])


%     Subsystem  'Subsystem2/Subsystem4'.

new_system([sys,'/','Subsystem2/Subsystem4'])
set_param([sys,'/','Subsystem2/Subsystem4'],'Location',[274,618,883,973])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem4/Ecart teta_ref - teta'])
set_param([sys,'/','Subsystem2/Subsystem4/Ecart teta_ref - teta'],...
		'position',[70,40,75,45])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem4/Rappel proportionnel'])
set_param([sys,'/','Subsystem2/Subsystem4/Rappel proportionnel'],...
		'position',[190,95,195,100])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem4/gain 0 ou 1'])
set_param([sys,'/','Subsystem2/Subsystem4/gain 0 ou 1'],...
		'Gain','0',...
		'position',[255,207,285,233])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem4/Gain'])
set_param([sys,'/','Subsystem2/Subsystem4/Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PD',...
		'position',[160,61,235,99])

add_block('built-in/Inport',[sys,'/','Subsystem2/Subsystem4/in_1'])
set_param([sys,'/','Subsystem2/Subsystem4/in_1'],...
		'position',[55,70,75,90])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Subsystem4/Intgrateur'])
set_param([sys,'/','Subsystem2/Subsystem4/Intgrateur'],...
		'BackGround',7,...
		'Numerator','[I_PD]',...
		'Denominator','[1 0]',...
		'position',[155,199,225,241])

add_block('built-in/Derivative',[sys,'/','Subsystem2/Subsystem4/Derivative'])
set_param([sys,'/','Subsystem2/Subsystem4/Derivative'],...
		'position',[155,130,200,170])

add_block('built-in/Sum',[sys,'/','Subsystem2/Subsystem4/Sum'])
set_param([sys,'/','Subsystem2/Subsystem4/Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[325,42,355,258])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem4/ROUE'])
set_param([sys,'/','Subsystem2/Subsystem4/ROUE'],...
		'hide name',0,...
		'position',[239,75,244,80])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem4/Gain1'])
set_param([sys,'/','Subsystem2/Subsystem4/Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PD',...
		'position',[235,129,290,171])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Subsystem4/Filtre passe bas'])
set_param([sys,'/','Subsystem2/Subsystem4/Filtre passe bas'],...
		'Denominator','[1 1/0.8]',...
		'position',[455,125,515,175])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem4/Gain2'])
set_param([sys,'/','Subsystem2/Subsystem4/Gain2'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','gain_roue',...
		'position',[375,129,430,171])

add_block('built-in/Outport',[sys,'/','Subsystem2/Subsystem4/commande_pid'])
set_param([sys,'/','Subsystem2/Subsystem4/commande_pid'],...
		'position',[555,140,575,160])
add_line([sys,'/','Subsystem2/Subsystem4'],[290,220;320,220])
add_line([sys,'/','Subsystem2/Subsystem4'],[230,220;250,220])
add_line([sys,'/','Subsystem2/Subsystem4'],[295,150;320,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[205,150;230,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[240,80;320,80])
add_line([sys,'/','Subsystem2/Subsystem4'],[80,80;155,80])
add_line([sys,'/','Subsystem2/Subsystem4'],[520,150;550,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[110,80;110,220;150,220])
add_line([sys,'/','Subsystem2/Subsystem4'],[110,150;150,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[360,150;370,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[435,150;450,150])
set_param([sys,'/','Subsystem2/Subsystem4'],...
		'Mask Display','P.I.D TANGAGE')


%     Finished composite block 'Subsystem2/Subsystem4'.

set_param([sys,'/','Subsystem2/Subsystem4'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[340,524,465,586])

add_block('built-in/Note',[sys,'/','Subsystem2/PID teta'])
set_param([sys,'/','Subsystem2/PID teta'],...
		'position',[415,590,420,595])


%     Subsystem  'Subsystem2/UnNamed4'.

new_system([sys,'/','Subsystem2/UnNamed4'])
set_param([sys,'/','Subsystem2/UnNamed4'],'Location',[31,157,323,338])

add_block('built-in/Mux',[sys,'/','Subsystem2/UnNamed4/Mux'])
set_param([sys,'/','Subsystem2/UnNamed4/Mux'],...
		'inputs','2',...
		'position',[175,57,205,133])

add_block('built-in/Outport',[sys,'/','Subsystem2/UnNamed4/out_1'])
set_param([sys,'/','Subsystem2/UnNamed4/out_1'],...
		'position',[240,85,260,105])

add_block('built-in/Constant',[sys,'/','Subsystem2/UnNamed4/Constant3'])
set_param([sys,'/','Subsystem2/UnNamed4/Constant3'],...
		'hide name',0,...
		'Value','consigne_lacet',...
		'position',[25,104,130,126])

add_block('built-in/Constant',[sys,'/','Subsystem2/UnNamed4/Constant1'])
set_param([sys,'/','Subsystem2/UnNamed4/Constant1'],...
		'hide name',0,...
		'Value','consigne_roulis',...
		'position',[25,62,135,88])
add_line([sys,'/','Subsystem2/UnNamed4'],[140,75;170,75])
add_line([sys,'/','Subsystem2/UnNamed4'],[135,115;170,115])
add_line([sys,'/','Subsystem2/UnNamed4'],[210,95;235,95])
set_param([sys,'/','Subsystem2/UnNamed4'],...
		'Mask Display','Consigne\nroulis(1) lacet(2)')


%     Finished composite block 'Subsystem2/UnNamed4'.

set_param([sys,'/','Subsystem2/UnNamed4'],...
		'hide name',0,...
		'position',[235,117,330,153])


%     Subsystem  ['Subsystem2/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],'Location',[195,367,1041,836])


%     Subsystem  ['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

new_system([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],'Location',[27,258,1102,698])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']],...
		'position',[804,170,809,175])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']],...
		'position',[804,290,809,295])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']],...
		'position',[715,325,720,330])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[910,170,915,175])

add_block('built-in/Outport',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']],...
		'position',[965,230,985,250])

add_block('built-in/State-Space',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Axe x')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/',...
		'position',[415,93,470,127])

add_block('built-in/Demux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']],...
		'outputs','3',...
		'position',[520,44,580,76])

add_block('built-in/Mux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,100,565,135])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']],...
		'position',[784,215,789,220])

add_block('built-in/Mux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[820,220,865,260])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']],...
		'position',[730,205,735,210])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']],...
		'position',[740,75,745,80])

add_block('built-in/Sum',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']],...
		'hide name',0,...
		'position',[755,95,775,130])

add_block('built-in/State-Space',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Axe y')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/',...
		'position',[415,223,470,257])

add_block('built-in/Mux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,230,565,265])

add_block('built-in/Sum',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'hide name',0,...
		'position',[755,220,770,260])

add_block('built-in/Sum',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'hide name',0,...
		'position',[755,339,790,381])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1',...
		'position',[615,349,675,391])

add_block('built-in/State-Space',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Axe z')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/',...
		'position',[415,338,470,372])

add_block('built-in/Mux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[540,344,570,391])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']],...
		'position',[439,145,444,150])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1',...
		'position',[600,104,665,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1',...
		'position',[590,234,665,266])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[305,25,310,30])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']],...
		'position',[85,65,90,70])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[180,85,355,135])

add_block('built-in/Clock',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']],...
		'position',[115,100,135,120])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']],...
		'position',[273,165,278,170])

add_block('built-in/Inport',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']],...
		'position',[120,160,140,180])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[795,360;795,255;815,255])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[780,115;795,115;795,225;815,225])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,50;720,50;720,105;750,105])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,60;705,60;705,230;750,230])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,70;690,70;690,350;750,350])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[360,110;410,110])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,60;515,60])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[775,240;815,240])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,355;410,355])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,240;410,240])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[145,170;510,170;510,125;530,125])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,170;510,380;535,380])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,255;530,255])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[680,370;750,370])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,355;535,355])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[575,370;610,370])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,250;585,250])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,240;530,240])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,250;750,250])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,120;750,120])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,110;530,110])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,120;595,120])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[870,240;960,240])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[140,110;175,110])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[405,84,540,156])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Angles']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Angles']],...
		'position',[350,135,355,140])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[660,150,665,155])

add_block('built-in/Inport',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[285,110,305,130])

add_block('built-in/Outport',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[615,110,635,130])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']],...
		'position',[305,160,310,165])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[460,30,465,35])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],[545,120;610,120])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],[310,120;400,120])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Subsystem2/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],...
		'position',[230,278,430,352])

add_block('built-in/Demux',[sys,'/','Subsystem2/Demux1'])
set_param([sys,'/','Subsystem2/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[455,259,500,371])

add_block('built-in/Sum',[sys,'/','Subsystem2/Sum1'])
set_param([sys,'/','Subsystem2/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[355,115,385,190])

add_block('built-in/Note',[sys,'/',['Subsystem2/Sortie roulis(1)',13,'lacet(2)']])
set_param([sys,'/',['Subsystem2/Sortie roulis(1)',13,'lacet(2)']],...
		'position',[305,175,310,180])

add_block('built-in/Demux',[sys,'/','Subsystem2/Demux'])
set_param([sys,'/','Subsystem2/Demux'],...
		'hide name',0,...
		'outputs','2',...
		'position',[405,98,440,207])


%     Subsystem  'Subsystem2/Subsystem2'.

new_system([sys,'/','Subsystem2/Subsystem2'])
set_param([sys,'/','Subsystem2/Subsystem2'],'Location',[4,50,856,463])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem2/Gain2'])
set_param([sys,'/','Subsystem2/Subsystem2/Gain2'],...
		'Gain','gain_roulis',...
		'position',[595,232,620,258])

add_block('built-in/Transfer Fcn',[sys,'/',['Subsystem2/Subsystem2/Filtre passe bas',13,'roulis']])
set_param([sys,'/',['Subsystem2/Subsystem2/Filtre passe bas',13,'roulis']],...
		'Denominator','[1 1/0.8]',...
		'position',[680,220,740,270])

add_block('built-in/Outport',[sys,'/','Subsystem2/Subsystem2/out_1'])
set_param([sys,'/','Subsystem2/Subsystem2/out_1'],...
		'position',[775,235,795,255])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem2/Gain1'])
set_param([sys,'/','Subsystem2/Subsystem2/Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_ROULIS*5',...
		'position',[445,224,500,266])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem2/ROUE'])
set_param([sys,'/','Subsystem2/Subsystem2/ROUE'],...
		'hide name',0,...
		'position',[449,170,454,175])

add_block('built-in/Sum',[sys,'/','Subsystem2/Subsystem2/Sum'])
set_param([sys,'/','Subsystem2/Subsystem2/Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[535,137,565,353])

add_block('built-in/Derivative',[sys,'/','Subsystem2/Subsystem2/Derivative'])
set_param([sys,'/','Subsystem2/Subsystem2/Derivative'],...
		'position',[365,225,410,265])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Subsystem2/Intgrateur'])
set_param([sys,'/','Subsystem2/Subsystem2/Intgrateur'],...
		'BackGround',7,...
		'Numerator','[I_PID_ROULIS]',...
		'Denominator','[1 0]',...
		'position',[350,294,435,336])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Subsystem2/Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_ROULIS',...
		'position',[370,156,445,194])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem2/gain 0 ou 1'])
set_param([sys,'/','Subsystem2/Subsystem2/gain 0 ou 1'],...
		'Gain','1/2',...
		'position',[465,302,495,328])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem2/Rappel proportionnel'])
set_param([sys,'/','Subsystem2/Subsystem2/Rappel proportionnel'],...
		'position',[400,190,405,195])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem2/roulisref - roulis '])
set_param([sys,'/','Subsystem2/Subsystem2/roulisref - roulis '],...
		'position',[280,135,285,140])

add_block('built-in/Note',[sys,'/',['Subsystem2/Subsystem2/Rappel',13,'proportionnel']])
set_param([sys,'/',['Subsystem2/Subsystem2/Rappel',13,'proportionnel']],...
		'ForeGround',1,...
		'position',[465,140,470,145])

add_block('built-in/Inport',[sys,'/','Subsystem2/Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/Subsystem2/in_1'],...
		'position',[265,165,285,185])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem2/PID ROULIS'])
set_param([sys,'/','Subsystem2/Subsystem2/PID ROULIS'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[510,70,515,75])
add_line([sys,'/','Subsystem2/Subsystem2'],[745,245;770,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[500,315;530,315])
add_line([sys,'/','Subsystem2/Subsystem2'],[440,315;460,315])
add_line([sys,'/','Subsystem2/Subsystem2'],[505,245;530,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[415,245;440,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[450,175;530,175])
add_line([sys,'/','Subsystem2/Subsystem2'],[290,175;365,175])
add_line([sys,'/','Subsystem2/Subsystem2'],[345,175;320,175;320,315;345,315])
add_line([sys,'/','Subsystem2/Subsystem2'],[320,245;360,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[625,245;675,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[570,245;590,245])
set_param([sys,'/','Subsystem2/Subsystem2'],...
		'Mask Display','PID ROULIS SEUL')


%     Finished composite block 'Subsystem2/Subsystem2'.

set_param([sys,'/','Subsystem2/Subsystem2'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[470,98,620,152])


%     Subsystem  'Subsystem2/Subsystem3'.

new_system([sys,'/','Subsystem2/Subsystem3'])
set_param([sys,'/','Subsystem2/Subsystem3'],'Location',[133,130,823,495])

add_block('built-in/Note',[sys,'/',['Subsystem2/Subsystem3/Rappel',13,'proportionnel1']])
set_param([sys,'/',['Subsystem2/Subsystem3/Rappel',13,'proportionnel1']],...
		'ForeGround',1,...
		'position',[315,75,320,80])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem3/lacet_ref - lacet  '])
set_param([sys,'/','Subsystem2/Subsystem3/lacet_ref - lacet  '],...
		'position',[125,90,130,95])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem3/Rappel proportionnel1'])
set_param([sys,'/','Subsystem2/Subsystem3/Rappel proportionnel1'],...
		'position',[245,145,250,150])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem3/gain 0 ou 2'])
set_param([sys,'/','Subsystem2/Subsystem3/gain 0 ou 2'],...
		'Gain','1*2',...
		'position',[310,257,340,283])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem3/Gain2'])
set_param([sys,'/','Subsystem2/Subsystem3/Gain2'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_LACET*2',...
		'position',[215,111,290,149])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Subsystem3/Intgrateur1'])
set_param([sys,'/','Subsystem2/Subsystem3/Intgrateur1'],...
		'BackGround',7,...
		'Numerator','[I_PID_LACET]',...
		'Denominator','[1 0]',...
		'position',[210,249,280,291])

add_block('built-in/Derivative',[sys,'/','Subsystem2/Subsystem3/Derivative1'])
set_param([sys,'/','Subsystem2/Subsystem3/Derivative1'],...
		'position',[210,180,255,220])

add_block('built-in/Sum',[sys,'/','Subsystem2/Subsystem3/Sum1'])
set_param([sys,'/','Subsystem2/Subsystem3/Sum1'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[380,92,410,308])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem3/ROUE1'])
set_param([sys,'/','Subsystem2/Subsystem3/ROUE1'],...
		'hide name',0,...
		'position',[294,125,299,130])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem3/Gain3'])
set_param([sys,'/','Subsystem2/Subsystem3/Gain3'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_LACET*5',...
		'position',[290,179,345,221])

add_block('built-in/Outport',[sys,'/','Subsystem2/Subsystem3/out_1'])
set_param([sys,'/','Subsystem2/Subsystem3/out_1'],...
		'position',[580,190,600,210])

add_block('built-in/Inport',[sys,'/','Subsystem2/Subsystem3/in_1'])
set_param([sys,'/','Subsystem2/Subsystem3/in_1'],...
		'position',[115,120,135,140])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem3/Gain4'])
set_param([sys,'/','Subsystem2/Subsystem3/Gain4'],...
		'Gain','gain_lacet',...
		'position',[440,187,465,213])

add_block('built-in/Transfer Fcn',[sys,'/',['Subsystem2/Subsystem3/Filtre passe bas',13,'lacet']])
set_param([sys,'/',['Subsystem2/Subsystem3/Filtre passe bas',13,'lacet']],...
		'Denominator','[1 1/0.8]',...
		'position',[485,175,545,225])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem3/PID LACET'])
set_param([sys,'/','Subsystem2/Subsystem3/PID LACET'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[335,20,340,25])
add_line([sys,'/','Subsystem2/Subsystem3'],[140,130;210,130])
add_line([sys,'/','Subsystem2/Subsystem3'],[190,130;165,130;165,270;205,270])
add_line([sys,'/','Subsystem2/Subsystem3'],[165,200;205,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[295,130;375,130])
add_line([sys,'/','Subsystem2/Subsystem3'],[260,200;285,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[350,200;375,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[285,270;305,270])
add_line([sys,'/','Subsystem2/Subsystem3'],[345,270;375,270])
add_line([sys,'/','Subsystem2/Subsystem3'],[550,200;575,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[470,200;480,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[415,200;435,200])
set_param([sys,'/','Subsystem2/Subsystem3'],...
		'Mask Display','PID LACET SEUL')


%     Finished composite block 'Subsystem2/Subsystem3'.

set_param([sys,'/','Subsystem2/Subsystem3'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[470,153,620,207])

add_block('built-in/Fcn',[sys,'/','Subsystem2/Fcn'])
set_param([sys,'/','Subsystem2/Fcn'],...
		'Expr','1/u',...
		'position',[525,305,565,325])

add_block('built-in/Mux',[sys,'/','Subsystem2/Mux2'])
set_param([sys,'/','Subsystem2/Mux2'],...
		'hide name',0,...
		'inputs','[1 1 1]',...
		'position',[815,218,835,322])

add_block('built-in/Note',[sys,'/','Subsystem2/Couple commande sur le tangage'])
set_param([sys,'/','Subsystem2/Couple commande sur le tangage'],...
		'position',[795,585,800,590])

add_block('built-in/Product',[sys,'/','Subsystem2/Product2'])
set_param([sys,'/','Subsystem2/Product2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[695,411,725,449])

add_block('built-in/Product',[sys,'/','Subsystem2/Product3'])
set_param([sys,'/','Subsystem2/Product3'],...
		'hide name',0,...
		'inputs','3',...
		'position',[695,501,725,539])

add_block('built-in/Product',[sys,'/','Subsystem2/Product'])
set_param([sys,'/','Subsystem2/Product'],...
		'hide name',0,...
		'position',[690,171,720,209])

add_block('built-in/Note',[sys,'/','Subsystem2/mx'])
set_param([sys,'/','Subsystem2/mx'],...
		'position',[705,150,710,155])

add_block('built-in/Note',[sys,'/','Subsystem2/mz'])
set_param([sys,'/','Subsystem2/mz'],...
		'position',[705,90,710,95])

add_block('built-in/Product',[sys,'/','Subsystem2/Product1'])
set_param([sys,'/','Subsystem2/Product1'],...
		'hide name',0,...
		'position',[690,111,720,149])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[650,108,675,132])

add_block('built-in/Note',[sys,'/','Subsystem2/1//By'])
set_param([sys,'/','Subsystem2/1//By'],...
		'position',[540,285,545,290])

add_block('built-in/Sum',[sys,'/','Subsystem2/Sum'])
set_param([sys,'/','Subsystem2/Sum'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[755,398,775,582])

add_block('built-in/Note',[sys,'/',['Subsystem2/Moment cr par',13,'magntocoupleurs']])
set_param([sys,'/',['Subsystem2/Moment cr par',13,'magntocoupleurs']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[1115,410,1120,415])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem2/MATLAB Fcn1'])
set_param([sys,'/','Subsystem2/MATLAB Fcn1'],...
		'MATLAB Fcn','saturmm(u)',...
		'Output Width','3',...
		'position',[855,253,915,287])

add_block('built-in/Demux',[sys,'/','Subsystem2/Demux2'])
set_param([sys,'/','Subsystem2/Demux2'],...
		'hide name',0,...
		'outputs','3',...
		'position',[935,214,965,326])

add_block('built-in/Note',[sys,'/',['Subsystem2/COUPLE ROUE',13,'DIMENSION 1']])
set_param([sys,'/',['Subsystem2/COUPLE ROUE',13,'DIMENSION 1']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[1115,630,1120,635])

add_block('built-in/Outport',[sys,'/','Subsystem2/out_3'])
set_param([sys,'/','Subsystem2/out_3'],...
		'Port','2',...
		'position',[1130,590,1150,610])

add_block('built-in/Note',[sys,'/','Subsystem2/Champ B axes satellite'])
set_param([sys,'/','Subsystem2/Champ B axes satellite'],...
		'position',[895,385,900,390])

add_block('built-in/Note',[sys,'/',['Subsystem2/moment',13,'magn']])
set_param([sys,'/',['Subsystem2/moment',13,'magn']],...
		'position',[825,320,830,325])

add_block('built-in/Mux',[sys,'/','Subsystem2/Mux4'])
set_param([sys,'/','Subsystem2/Mux4'],...
		'hide name',0,...
		'inputs','3',...
		'position',[1035,199,1070,261])

add_block('built-in/Constant',[sys,'/','Subsystem2/Constant1'])
set_param([sys,'/','Subsystem2/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[995,220,1015,240])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace1'])
set_param([sys,'/','Subsystem2/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[1015,162,1065,178])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[1025,282,1075,298])

add_block('built-in/Note',[sys,'/',['Subsystem2/Moments magntiques',13,'des bobines']])
set_param([sys,'/',['Subsystem2/Moments magntiques',13,'des bobines']],...
		'position',[990,110,995,115])

add_block('built-in/Note',[sys,'/',['Subsystem2/Limiteurs de',13,'moments magntiques']])
set_param([sys,'/',['Subsystem2/Limiteurs de',13,'moments magntiques']],...
		'position',[870,155,875,160])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem2/MATLAB Fcn'])
set_param([sys,'/','Subsystem2/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'Mask Display','M vect B',...
		'position',[1155,258,1215,292])

add_block('built-in/Mux',[sys,'/','Subsystem2/Mux3'])
set_param([sys,'/','Subsystem2/Mux3'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[1105,189,1130,356])

add_block('built-in/Outport',[sys,'/','Subsystem2/out_2'])
set_param([sys,'/','Subsystem2/out_2'],...
		'position',[1235,265,1255,285])
add_line([sys,'/','Subsystem2'],[390,155;400,155])
add_line([sys,'/','Subsystem2'],[335,135;350,135])
add_line([sys,'/','Subsystem2'],[90,130;170,130])
add_line([sys,'/','Subsystem2'],[90,210;170,210])
add_line([sys,'/','Subsystem2'],[225,170;350,170])
add_line([sys,'/','Subsystem2'],[25,150;35,150])
add_line([sys,'/','Subsystem2'],[220,315;225,315])
add_line([sys,'/','Subsystem2'],[155,130;160,130;170,290])
add_line([sys,'/','Subsystem2'],[90,170;125,170;125,315;170,315])
add_line([sys,'/','Subsystem2'],[310,555;335,555])
add_line([sys,'/','Subsystem2'],[245,535;270,535])
add_line([sys,'/','Subsystem2'],[100,210;100,340;170,340])
add_line([sys,'/','Subsystem2'],[115,170;115,570;270,570])
add_line([sys,'/','Subsystem2'],[435,315;450,315])
add_line([sys,'/','Subsystem2'],[445,180;465,180])
add_line([sys,'/','Subsystem2'],[445,125;465,125])
add_line([sys,'/','Subsystem2'],[505,315;520,315])
add_line([sys,'/','Subsystem2'],[625,180;685,180])
add_line([sys,'/','Subsystem2'],[570,315;675,315;685,200])
add_line([sys,'/','Subsystem2'],[625,125;645,120])
add_line([sys,'/','Subsystem2'],[680,120;685,120])
add_line([sys,'/','Subsystem2'],[665,315;665,140;685,140])
add_line([sys,'/','Subsystem2'],[625,125;625,430;690,430])
add_line([sys,'/','Subsystem2'],[505,280;580,280;580,440;690,440])
add_line([sys,'/','Subsystem2'],[665,315;665,510;690,510])
add_line([sys,'/','Subsystem2'],[505,350;540,350;540,530;690,530])
add_line([sys,'/','Subsystem2'],[646,180;645,520;690,520])
add_line([sys,'/','Subsystem2'],[470,555;750,550])
add_line([sys,'/','Subsystem2'],[730,430;750,430])
add_line([sys,'/','Subsystem2'],[730,520;735,520;735,490;750,490])
add_line([sys,'/','Subsystem2'],[1220,275;1230,275])
add_line([sys,'/','Subsystem2'],[725,190;770,190;770,235;810,235])
add_line([sys,'/','Subsystem2'],[725,130;740,130;740,270;810,270])
add_line([sys,'/','Subsystem2'],[780,490;800,490;810,305])
add_line([sys,'/','Subsystem2'],[840,270;850,270])
add_line([sys,'/','Subsystem2'],[1135,275;1150,275])
add_line([sys,'/','Subsystem2'],[920,270;930,270])
add_line([sys,'/','Subsystem2'],[970,305;985,305;985,600;1125,600])
add_line([sys,'/','Subsystem2'],[435,315;435,385;1075,385;1075,315;1100,315])
add_line([sys,'/','Subsystem2'],[1075,230;1100,230])
add_line([sys,'/','Subsystem2'],[970,235;985,235;985,210;1030,210])
add_line([sys,'/','Subsystem2'],[970,270;995,270;995,250;1030,250])
add_line([sys,'/','Subsystem2'],[1020,230;1030,230])
add_line([sys,'/','Subsystem2'],[265,170;265,195])
add_line([sys,'/','Subsystem2'],[985,210;985,170;1010,170])
add_line([sys,'/','Subsystem2'],[995,270;995,290;1020,290])
add_line([sys,'/','Subsystem2'],[665,420;690,420])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','4 - COMMANDE 2 AXES ROULIS-LACET\n\nAVEC 2 BOBINES ROULIS-LACET\n\n5 - COMMANDE TANGAGE SEUL PAR ROUE')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',11,...
		'position',[90,480,440,580])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,157,1218,855])
open_system([sys,'/','Subsystem'])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre du couple roue',13,'dimension 1']])
set_param([sys,'/',['Subsystem/Entre du couple roue',13,'dimension 1']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[110,320,115,325])

add_block('built-in/Inport',[sys,'/','Subsystem/Inport'])
set_param([sys,'/','Subsystem/Inport'],...
		'position',[140,280,160,300])

add_block('built-in/Note',[sys,'/','Subsystem/Vitesse roue'])
set_param([sys,'/','Subsystem/Vitesse roue'],...
		'position',[415,320,420,325])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','couple_roue',...
		'buffer','points_trace',...
		'position',[390,174,495,206])

add_block('built-in/Integrator',[sys,'/','Subsystem/Integrator2'])
set_param([sys,'/','Subsystem/Integrator2'],...
		'BackGround',7,...
		'Initial','rotation_initiale',...
		'position',[415,238,460,282])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain5'])
set_param([sys,'/','Subsystem/Gain5'],...
		'BackGround',7,...
		'Gain','1/J',...
		'position',[355,240,390,280])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[665,245,745,275])

add_block('built-in/Gain',[sys,'/',['Subsystem/Inversion',13,'signe1']])
set_param([sys,'/',['Subsystem/Inversion',13,'signe1']],...
		'orientation',1,...
		'ForeGround',7,...
		'position',[525,285,555,315])

add_block('built-in/Gain',[sys,'/',['Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']])
set_param([sys,'/',['Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']],...
		'Gain','-1',...
		'position',[285,247,315,273])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain1'])
set_param([sys,'/','Subsystem/Gain1'],...
		'position',[600,408,625,442])


%     Subsystem  'Subsystem/Subsystem1'.

new_system([sys,'/','Subsystem/Subsystem1'])
set_param([sys,'/','Subsystem/Subsystem1'],'Location',[4,135,1217,1003])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/Entre de la vitesse ',13,'de la roue']])
set_param([sys,'/',['Subsystem/Subsystem1/Entre de la vitesse ',13,'de la roue']],...
		'position',[1290,650,1295,655])

add_block('built-in/Product',[sys,'/','Subsystem/Subsystem1/Product2'])
set_param([sys,'/','Subsystem/Subsystem1/Product2'],...
		'inputs','4',...
		'position',[830,359,850,666])

add_block('built-in/Product',[sys,'/','Subsystem/Subsystem1/Product3'])
set_param([sys,'/','Subsystem/Subsystem1/Product3'],...
		'position',[910,291,930,424])

add_block('built-in/To Workspace',[sys,'/','Subsystem/Subsystem1/To Workspace1'])
set_param([sys,'/','Subsystem/Subsystem1/To Workspace1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','couple_desat',...
		'buffer','points_trace',...
		'position',[975,434,1070,486])

add_block('built-in/Outport',[sys,'/','Subsystem/Subsystem1/out_1'])
set_param([sys,'/','Subsystem/Subsystem1/out_1'],...
		'position',[1040,350,1060,370])

add_block('built-in/Clock',[sys,'/','Subsystem/Subsystem1/Clock1'])
set_param([sys,'/','Subsystem/Subsystem1/Clock1'],...
		'hide name',0,...
		'position',[90,299,110,321])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem1/Constant4'])
set_param([sys,'/','Subsystem/Subsystem1/Constant4'],...
		'hide name',0,...
		'position',[735,382,790,418])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/Couple appliqu',13,'au satellite',13,'sur le tangage']])
set_param([sys,'/',['Subsystem/Subsystem1/Couple appliqu',13,'au satellite',13,'sur le tangage']],...
		'position',[1030,280,1035,285])

add_block('built-in/Gain',[sys,'/','Subsystem/Subsystem1/Gain'])
set_param([sys,'/','Subsystem/Subsystem1/Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,108,410,132])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/Couple C(t) de',13,'dsaturation']])
set_param([sys,'/',['Subsystem/Subsystem1/Couple C(t) de',13,'dsaturation']],...
		'BackGround',7,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[240,50,245,55])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/Calibrage',13,'du couple']])
set_param([sys,'/',['Subsystem/Subsystem1/Calibrage',13,'du couple']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[370,50,375,55])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/C(t)'])
set_param([sys,'/','Subsystem/Subsystem1/C(t)'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[400,140,405,145])

add_block('built-in/To Workspace',[sys,'/','Subsystem/Subsystem1/To Workspace2'])
set_param([sys,'/','Subsystem/Subsystem1/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','couple_C',...
		'buffer','points_trace',...
		'position',[480,94,575,146])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/Subsystem1/MATLAB Fcn6'])
set_param([sys,'/','Subsystem/Subsystem1/MATLAB Fcn6'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','liss_cpl(u,debut_desaturation,periode_orbitale)',...
		'Output Width','1',...
		'Mask Display','LISS_CPL')
set_param([sys,'/','Subsystem/Subsystem1/MATLAB Fcn6'],...
		'position',[200,103,290,137])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem/Subsystem1/Relational',13,'Operator3']])
set_param([sys,'/',['Subsystem/Subsystem1/Relational',13,'Operator3']],...
		'position',[705,436,735,509])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/Commutateurs commands 0  ou 1'])
set_param([sys,'/','Subsystem/Subsystem1/Commutateurs commands 0  ou 1'],...
		'position',[685,325,690,330])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem1/Constant5'])
set_param([sys,'/','Subsystem/Subsystem1/Constant5'],...
		'hide name',0,...
		'position',[750,617,805,653])

add_block('built-in/Sum',[sys,'/','Subsystem/Subsystem1/Sum1'])
set_param([sys,'/','Subsystem/Subsystem1/Sum1'],...
		'hide name',0,...
		'position',[620,169,645,211])

add_block('built-in/Inport',[sys,'/','Subsystem/Subsystem1/in_3'])
set_param([sys,'/','Subsystem/Subsystem1/in_3'],...
		'Port','2',...
		'position',[215,190,235,210])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/Entre couple roue classique'])
set_param([sys,'/','Subsystem/Subsystem1/Entre couple roue classique'],...
		'position',[255,230,260,235])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/Couple roue'])
set_param([sys,'/','Subsystem/Subsystem1/Couple roue'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[465,205,470,210])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem/Subsystem1/Relational',13,'Operator2']])
set_param([sys,'/',['Subsystem/Subsystem1/Relational',13,'Operator2']],...
		'Operator','<=',...
		'position',[705,571,735,644])

add_block('built-in/Inport',[sys,'/','Subsystem/Subsystem1/in_1'])
set_param([sys,'/','Subsystem/Subsystem1/in_1'],...
		'position',[315,580,335,600])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/Entre de la vitesse de la roue'])
set_param([sys,'/','Subsystem/Subsystem1/Entre de la vitesse de la roue'],...
		'position',[420,555,425,560])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem1/Constant3'])
set_param([sys,'/','Subsystem/Subsystem1/Constant3'],...
		'Value','rotation_maximale',...
		'position',[535,611,675,639])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/t <=debut_desaturation ',13,'=>    0']])
set_param([sys,'/',['Subsystem/Subsystem1/t <=debut_desaturation ',13,'=>    0']],...
		'position',[615,410,620,415])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem1/Constant7'])
set_param([sys,'/','Subsystem/Subsystem1/Constant7'],...
		'Value','debut_desaturation',...
		'position',[535,471,675,509])
add_line([sys,'/','Subsystem/Subsystem1'],[340,590;700,590])
add_line([sys,'/','Subsystem/Subsystem1'],[680,625;700,625])
add_line([sys,'/','Subsystem/Subsystem1'],[680,490;700,490])
add_line([sys,'/','Subsystem/Subsystem1'],[115,310;500,310;500,455;700,455])
add_line([sys,'/','Subsystem/Subsystem1'],[740,610;785,610;785,550;825,550])
add_line([sys,'/','Subsystem/Subsystem1'],[855,515;875,515;875,390;905,390])
add_line([sys,'/','Subsystem/Subsystem1'],[935,360;1035,360])
add_line([sys,'/','Subsystem/Subsystem1'],[955,360;955,460;970,460])
add_line([sys,'/','Subsystem/Subsystem1'],[240,200;615,200])
add_line([sys,'/','Subsystem/Subsystem1'],[795,400;825,400])
add_line([sys,'/','Subsystem/Subsystem1'],[650,190;815,190;815,325;905,325])
add_line([sys,'/','Subsystem/Subsystem1'],[155,310;155,120;195,120])
add_line([sys,'/','Subsystem/Subsystem1'],[740,475;825,475])
add_line([sys,'/','Subsystem/Subsystem1'],[295,120;310,120])
add_line([sys,'/','Subsystem/Subsystem1'],[415,120;425,120;425,180;615,180])
add_line([sys,'/','Subsystem/Subsystem1'],[425,120;475,120])
add_line([sys,'/','Subsystem/Subsystem1'],[810,635;810,625;825,625])
set_param([sys,'/','Subsystem/Subsystem1'],...
		'Mask Display','BLOC COMMANDE ET ACTION\nDESATURATION')


%     Finished composite block 'Subsystem/Subsystem1'.

set_param([sys,'/','Subsystem/Subsystem1'],...
		'position',[310,384,535,466])

add_block('built-in/Transport Delay',[sys,'/','Subsystem/Retard4'])
set_param([sys,'/','Subsystem/Retard4'],...
		'Delay Time','0.2',...
		'position',[675,409,735,441])

add_block('built-in/Transport Delay',[sys,'/','Subsystem/Retard3'])
set_param([sys,'/','Subsystem/Retard3'],...
		'Delay Time','0.2',...
		'position',[585,529,645,561])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre du couple ',13,'sur le satellite']])
set_param([sys,'/',['Subsystem/Entre du couple ',13,'sur le satellite']],...
		'position',[500,525,505,530])

add_block('built-in/Note',[sys,'/',['Subsystem/Reconstruction d''un',13,'couple de dimension 3']])
set_param([sys,'/',['Subsystem/Reconstruction d''un',13,'couple de dimension 3']],...
		'position',[910,615,915,620])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant3'])
set_param([sys,'/','Subsystem/Constant3'],...
		'Value','0',...
		'position',[830,450,850,470])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant2'])
set_param([sys,'/','Subsystem/Constant2'],...
		'Value','0',...
		'position',[830,380,850,400])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux1'])
set_param([sys,'/','Subsystem/Mux1'],...
		'inputs','3',...
		'position',[900,374,945,476])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','3',...
		'position',[905,494,950,596])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant'])
set_param([sys,'/','Subsystem/Constant'],...
		'Value','0',...
		'position',[835,500,855,520])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant1'])
set_param([sys,'/','Subsystem/Constant1'],...
		'Value','0',...
		'position',[835,570,855,590])

add_block('built-in/Note',[sys,'/','Subsystem/Axe tangage N2'])
set_param([sys,'/','Subsystem/Axe tangage N2'],...
		'position',[725,520,730,525])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[1085,535,1105,555])

add_block('built-in/Outport',[sys,'/','Subsystem/out_2'])
set_param([sys,'/','Subsystem/out_2'],...
		'Port','2',...
		'position',[1075,415,1095,435])

add_block('built-in/Note',[sys,'/','Subsystem/DESATURATION'])
set_param([sys,'/','Subsystem/DESATURATION'],...
		'position',[1075,375,1080,380])

add_block('built-in/Note',[sys,'/','Subsystem/ROUE'])
set_param([sys,'/','Subsystem/ROUE'],...
		'position',[1095,585,1100,590])

add_block('built-in/Note',[sys,'/',['Subsystem/Sortie couples',13,'roue et desaturation',13,'dimension 3']])
set_param([sys,'/',['Subsystem/Sortie couples',13,'roue et desaturation',13,'dimension 3']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1080,620,1085,625])

add_block('built-in/Note',[sys,'/','Subsystem/Comportement de la roue'])
set_param([sys,'/','Subsystem/Comportement de la roue'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',24,...
		'position',[615,25,620,30])


%     Subsystem  'Subsystem/Subsystem'.

new_system([sys,'/','Subsystem/Subsystem'])
set_param([sys,'/','Subsystem/Subsystem'],'Location',[652,89,1227,289])


%     Subsystem  ['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs'].

new_system([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']])
set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs/x']])
set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']],[90,65;125,65])
set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])')
set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']],...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']],...
		'Mask Entries','1000\/-6000\/6000\/''y-/m--/c-./w:/g*/ro/b+''\/')


%     Finished composite block ['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs'].

set_param([sys,'/',['Subsystem/Subsystem/Sortie de la vitesse roue',13,'en tours//mn degrs']],...
		'BackGround',2,...
		'position',[360,57,455,103])

add_block('built-in/Gain',[sys,'/',['Subsystem/Subsystem/Conversionn',13,'rd//s en tr//mn',13,'1']])
set_param([sys,'/',['Subsystem/Subsystem/Conversionn',13,'rd//s en tr//mn',13,'1']],...
		'Gain','30/pi',...
		'position',[100,67,130,93])

add_block('built-in/Inport',[sys,'/','Subsystem/Subsystem/in_1'])
set_param([sys,'/','Subsystem/Subsystem/in_1'],...
		'position',[15,70,35,90])


%     Subsystem  'Subsystem/Subsystem/Subsystem4'.

new_system([sys,'/','Subsystem/Subsystem/Subsystem4'])
set_param([sys,'/','Subsystem/Subsystem/Subsystem4'],'Location',[429,285,1217,578])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem/Subsystem4/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem/Subsystem/Subsystem4/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[385,190,390,195])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem/Subsystem/Subsystem4/Relational',13,'Operator']])
set_param([sys,'/',['Subsystem/Subsystem/Subsystem4/Relational',13,'Operator']],...
		'Operator','<=',...
		'position',[310,36,345,129])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem/Subsystem/Subsystem4/Stop Simulation'])
set_param([sys,'/','Subsystem/Subsystem/Subsystem4/Stop Simulation'],...
		'position',[410,68,450,102])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem/Subsystem4/Constant'])
set_param([sys,'/','Subsystem/Subsystem/Subsystem4/Constant'],...
		'Value','vit_roue_max',...
		'position',[100,47,285,73])

add_block('built-in/Inport',[sys,'/','Subsystem/Subsystem/Subsystem4/in_1'])
set_param([sys,'/','Subsystem/Subsystem/Subsystem4/in_1'],...
		'position',[125,95,145,115])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem/Subsystem4/Fixe  6000 tr//mn'])
set_param([sys,'/','Subsystem/Subsystem/Subsystem4/Fixe  6000 tr//mn'],...
		'position',[200,15,205,20])
add_line([sys,'/','Subsystem/Subsystem/Subsystem4'],[150,105;305,105])
add_line([sys,'/','Subsystem/Subsystem/Subsystem4'],[350,85;405,85])
add_line([sys,'/','Subsystem/Subsystem/Subsystem4'],[290,60;305,60])
set_param([sys,'/','Subsystem/Subsystem/Subsystem4'],...
		'Mask Display','STOP\nDESATURATION')


%     Finished composite block 'Subsystem/Subsystem/Subsystem4'.

set_param([sys,'/','Subsystem/Subsystem/Subsystem4'],...
		'ForeGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[335,138,490,192])
add_line([sys,'/','Subsystem/Subsystem'],[135,80;355,80])
add_line([sys,'/','Subsystem/Subsystem'],[210,80;210,165;330,165])
add_line([sys,'/','Subsystem/Subsystem'],[40,80;95,80])
set_param([sys,'/','Subsystem/Subsystem'],...
		'Mask Display','CONTRLE ROUE\n\nEN DESATURATION\n\nSTOP PROGRAMME')


%     Finished composite block 'Subsystem/Subsystem'.

set_param([sys,'/','Subsystem/Subsystem'],...
		'position',[635,93,920,187])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace6'])
set_param([sys,'/','Subsystem/To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vitesseroue',...
		'buffer','points_trace',...
		'position',[720,294,865,326])

add_block('built-in/Note',[sys,'/',['Subsystem/Le couple de dsaturation',13,'est de dimension 1',13,'sur l''axe tangage']])
set_param([sys,'/',['Subsystem/Le couple de dsaturation',13,'est de dimension 1',13,'sur l''axe tangage']],...
		'position',[720,320,725,325])
add_line([sys,'/','Subsystem'],[465,260;660,260])
add_line([sys,'/','Subsystem'],[540,260;540,280])
add_line([sys,'/','Subsystem'],[165,290;235,290;235,190;385,190])
add_line([sys,'/','Subsystem'],[235,260;280,260])
add_line([sys,'/','Subsystem'],[625,260;625,310;715,310])
add_line([sys,'/','Subsystem'],[320,260;350,260])
add_line([sys,'/','Subsystem'],[395,260;410,260])
add_line([sys,'/','Subsystem'],[860,580;900,580])
add_line([sys,'/','Subsystem'],[235,290;235,545;580,545])
add_line([sys,'/','Subsystem'],[955,545;1080,545])
add_line([sys,'/','Subsystem'],[540,425;595,425])
add_line([sys,'/','Subsystem'],[860,510;900,510])
add_line([sys,'/','Subsystem'],[540,320;540,350;275,350;275,405;305,405])
add_line([sys,'/','Subsystem'],[235,445;305,445])
add_line([sys,'/','Subsystem'],[630,425;670,425])
add_line([sys,'/','Subsystem'],[740,425;895,425])
add_line([sys,'/','Subsystem'],[650,545;900,545])
add_line([sys,'/','Subsystem'],[855,460;895,460])
add_line([sys,'/','Subsystem'],[855,390;895,390])
add_line([sys,'/','Subsystem'],[950,425;1070,425])
add_line([sys,'/','Subsystem'],[575,260;575,140;630,140])
set_param([sys,'/','Subsystem'],...
		'Mask Display','1- ROUE DE REACTION - COUPLE ROUE\n\n\n\n2- DESATURATION - COUPLE DESATURATION')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[95,224,445,386])

add_block('built-in/Gain',[sys,'/','Gain8'])
set_param([sys,'/','Gain8'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[510,492,545,518])

add_block('built-in/Gain',[sys,'/','Gain7'])
set_param([sys,'/','Gain7'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[510,412,545,438])

add_block('built-in/Gain',[sys,'/','Gain6'])
set_param([sys,'/','Gain6'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[500,252,535,278])

add_block('built-in/Gain',[sys,'/','Gain9'])
set_param([sys,'/','Gain9'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Gain','desat',...
		'position',[510,332,545,358])

add_block('built-in/Note',[sys,'/','Tous les couples intervenants'])
set_param([sys,'/','Tous les couples intervenants'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[280,170,285,175])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[293,692,793,906])

add_block('built-in/Inport',[sys,'/','Subsystem1/Inport'])
set_param([sys,'/','Subsystem1/Inport'],...
		'position',[50,80,70,100])


%     Subsystem  ['Subsystem1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],'Location',[-162,112,1105,668])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[1025,53,1055,157])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[835,58,980,82])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[835,93,980,117])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[835,128,980,152])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[935,165,940,170])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[1015,213,1045,317])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[825,218,970,242])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[825,253,970,277])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[825,288,970,312])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','+++',...
		'position',[1130,214,1165,316])

add_block('built-in/Outport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/out_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/out_1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'position',[1200,255,1220,275])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/B']],...
		'position',[560,385,565,390])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/M']],...
		'position',[565,285,570,290])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[170,333,315,357])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[170,298,315,322])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[170,263,315,287])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[360,258,390,362])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Vitesses',13,'inutiles']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Vitesses',13,'inutiles']],...
		'position',[190,380,195,385])

add_block('built-in/Inport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[50,450,70,470])

add_block('built-in/Demux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux4']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux4']],...
		'hide name',0,...
		'outputs','[3 1 1 1]',...
		'position',[95,380,140,540])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Tangage']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Tangage']],...
		'position',[175,455,180,460])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Roulis']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Roulis']],...
		'position',[170,415,175,420])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Lacet']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Lacet']],...
		'position',[165,495,170,500])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux4']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux4']],...
		'inputs','3',...
		'position',[225,424,265,506])


%     Subsystem  ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,367,1041,836])


%     Subsystem  ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

new_system([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],'Location',[27,258,1102,698])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']],...
		'position',[804,170,809,175])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']],...
		'position',[804,290,809,295])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']],...
		'position',[715,325,720,330])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[910,170,915,175])

add_block('built-in/Outport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']],...
		'position',[965,230,985,250])

add_block('built-in/State-Space',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Display','Axe x',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/',...
		'position',[415,93,470,127])

add_block('built-in/Demux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']],...
		'outputs','3',...
		'position',[520,44,580,76])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,100,565,135])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']],...
		'position',[784,215,789,220])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[820,220,865,260])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']],...
		'position',[730,205,735,210])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']],...
		'position',[740,75,745,80])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']],...
		'hide name',0,...
		'position',[755,95,775,130])

add_block('built-in/State-Space',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Display','Axe y',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/',...
		'position',[415,223,470,257])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,230,565,265])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'hide name',0,...
		'position',[755,220,770,260])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'hide name',0,...
		'position',[755,339,790,381])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'position',[615,349,675,391])

add_block('built-in/State-Space',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Display','Axe z',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'position',[415,338,470,372])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[540,344,570,391])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']],...
		'position',[439,145,444,150])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'position',[600,104,665,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'position',[590,234,665,266])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[305,25,310,30])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']],...
		'position',[85,65,90,70])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'position',[180,85,355,135])

add_block('built-in/Clock',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']],...
		'position',[115,100,135,120])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']],...
		'position',[273,165,278,170])

add_block('built-in/Inport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']],...
		'position',[120,160,140,180])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[795,360;795,255;815,255])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[780,115;795,115;795,225;815,225])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,50;720,50;720,105;750,105])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,60;705,60;705,230;750,230])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,70;690,70;690,350;750,350])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[360,110;410,110])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,60;515,60])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[775,240;815,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,355;410,355])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,240;410,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[145,170;510,170;510,125;530,125])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,170;510,380;535,380])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,255;530,255])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[680,370;750,370])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,355;535,355])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[575,370;610,370])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,250;585,250])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,240;530,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,250;750,250])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,120;750,120])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,110;530,110])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,120;595,120])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[870,240;960,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[140,110;175,110])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[405,84,540,156])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Angles']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Angles']],...
		'position',[350,135,355,140])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[660,150,665,155])

add_block('built-in/Inport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[285,110,305,130])

add_block('built-in/Outport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[615,110,635,130])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']],...
		'position',[305,160,310,165])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[460,30,465,35])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[545,120;610,120])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[310,120;400,120])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[290,428,490,502])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[580,256,625,474])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[680,348,740,382])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[465,40,470,45])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[285,216,290,221])

add_block('built-in/Demux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux5']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux5']],...
		'hide name',0,...
		'outputs','[3 1 1 1]',...
		'position',[25,380,70,540])

add_block('built-in/To Workspace',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[935,410,1055,440])

add_block('built-in/Gain',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[415,285,530,335])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[810,408,870,442])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[730,247,735,252])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[920,369,925,374])

add_block('built-in/Gain',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[840,352,875,378])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[1060,105;1115,105;1125,230])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[1170,265;1195,265])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[975,300;1010,300])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[1050,265;1125,265])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[975,265;1010,265])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[975,230;1010,230])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[985,140;1020,140])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[985,105;1020,105])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[985,70;1020,70])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[320,345;355,345])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[320,310;355,310])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[320,275;355,275])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[395,310;410,310])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[535,310;575,310])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[270,465;285,465])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[145,440;220,440])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[145,480;205,480;205,465;220,465])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[145,520;185,520;185,490;220,490])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[75,460;90,460])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[495,465;510,465;510,420;575,420])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[630,365;675,365])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[745,365;775,365;775,425;805,425])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[875,425;930,425])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[775,365;835,365])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[880,365;1095,365;1095,300;1125,300])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Subsystem1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[100,62,230,118])

add_block('built-in/Gain',[sys,'/','Subsystem1/Gain3'])
set_param([sys,'/','Subsystem1/Gain3'],...
		'hide name',0,...
		'position',[270,77,305,103])

add_block('built-in/Outport',[sys,'/','Subsystem1/out_1'])
set_param([sys,'/','Subsystem1/out_1'],...
		'position',[410,80,430,100])

add_block('built-in/To Workspace',[sys,'/','Subsystem1/To Workspace10'])
set_param([sys,'/','Subsystem1/To Workspace10'],...
		'hide name',0,...
		'mat-name','cpl_pert',...
		'buffer','points_trace',...
		'position',[375,50,480,70])
add_line([sys,'/','Subsystem1'],[235,90;265,90])
add_line([sys,'/','Subsystem1'],[310,90;405,90])
add_line([sys,'/','Subsystem1'],[75,90;95,90])
add_line([sys,'/','Subsystem1'],[340,90;340,60;370,60])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','3 - PERTURBATIONS\n\nFournir la direction\ndu moment rsiduel')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[95,389,445,461])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'Font Weight','bold',...
		'Font Size',16,...
		'inputs','++++',...
		'position',[610,222,655,548])

add_block('built-in/Note',[sys,'/','U'])
set_param([sys,'/','U'],...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[630,335,635,340])

add_block('built-in/Gain',[sys,'/','Gain5'])
set_param([sys,'/','Gain5'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[695,372,730,398])

add_block('built-in/Note',[sys,'/',['Vecteur ',13,'Commande',13,'du second membre',13,'de l''quation d''tat']])
set_param([sys,'/',['Vecteur ',13,'Commande',13,'du second membre',13,'de l''quation d''tat']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[615,135,620,140])

add_block('built-in/Note',[sys,'/','Retour du couple roue'])
set_param([sys,'/','Retour du couple roue'],...
		'position',[245,590,250,595])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[429,285,1217,578])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/Gain',[sys,'/','Subsystem3/Gain'])
set_param([sys,'/','Subsystem3/Gain'],...
		'BackGround',7,...
		'Gain','(1-desat)*1*0',...
		'position',[475,68,555,102])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem3/fonction ',13,'d''arrt',13,'suivant angles et vitesses']])
set_param([sys,'/',['Subsystem3/fonction ',13,'d''arrt',13,'suivant angles et vitesses']],...
		'MATLAB Fcn','stopacqf(u)',...
		'Output Width','1',...
		'position',[345,68,405,102])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux'])
set_param([sys,'/','Subsystem3/Mux'],...
		'inputs','[3 3]',...
		'position',[225,55,250,115])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux'])
set_param([sys,'/','Subsystem3/Demux'],...
		'outputs','[3 3]',...
		'position',[60,31,95,129])

add_block('built-in/Note',[sys,'/','Subsystem3/Angles'])
set_param([sys,'/','Subsystem3/Angles'],...
		'position',[120,105,125,110])

add_block('built-in/Note',[sys,'/','Subsystem3/vitesses'])
set_param([sys,'/','Subsystem3/vitesses'],...
		'position',[120,30,125,35])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem3/Stop Simulation'])
set_param([sys,'/','Subsystem3/Stop Simulation'],...
		'position',[590,68,630,102])

add_block('built-in/Note',[sys,'/','Subsystem3/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem3/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[385,190,390,195])
add_line([sys,'/','Subsystem3'],[410,85;470,85])
add_line([sys,'/','Subsystem3'],[560,85;585,85])
add_line([sys,'/','Subsystem3'],[40,80;55,80])
add_line([sys,'/','Subsystem3'],[100,55;150,55;150,100;220,100])
add_line([sys,'/','Subsystem3'],[100,105;185,105;185,70;220,70])
add_line([sys,'/','Subsystem3'],[255,85;340,85])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','STOP\nMODE FIN')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[680,423,865,477])

add_block('built-in/Note',[sys,'/','Mc'])
set_param([sys,'/','Mc'],...
		'position',[665,390,670,395])


%     Subsystem  'Subsystem5'.

new_system([sys,'/','Subsystem5'])
set_param([sys,'/','Subsystem5'],'Location',[322,147,887,712])
open_system([sys,'/','Subsystem5'])


%     Subsystem  'Subsystem5/Subsystem'.

new_system([sys,'/','Subsystem5/Subsystem'])
set_param([sys,'/','Subsystem5/Subsystem'],'Location',[144,265,1149,864])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/rotation',13,'absolue']])
set_param([sys,'/',['Subsystem5/Subsystem/rotation',13,'absolue']],...
		'hide name',0,...
		'position',[540,95,545,100])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/wo phi'])
set_param([sys,'/','Subsystem5/Subsystem/wo phi'],...
		'hide name',0,...
		'position',[275,215,280,220])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/psi prime'])
set_param([sys,'/','Subsystem5/Subsystem/psi prime'],...
		'hide name',0,...
		'position',[295,175,300,180])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/teta prime'])
set_param([sys,'/','Subsystem5/Subsystem/teta prime'],...
		'hide name',0,...
		'position',[280,85,285,90])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/phi prime'])
set_param([sys,'/','Subsystem5/Subsystem/phi prime'],...
		'hide name',0,...
		'position',[270,45,275,50])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem/Constant'])
set_param([sys,'/','Subsystem5/Subsystem/Constant'],...
		'hide name',0,...
		'Value','vitesse_rotation',...
		'position',[235,119,335,141])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum1'])
set_param([sys,'/','Subsystem5/Subsystem/Sum1'],...
		'hide name',0,...
		'position',[365,107,385,138])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum'])
set_param([sys,'/','Subsystem5/Subsystem/Sum'],...
		'hide name',0,...
		'position',[365,70,385,90])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum2'])
set_param([sys,'/','Subsystem5/Subsystem/Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[360,188,385,232])

add_block('built-in/Mux',[sys,'/','Subsystem5/Subsystem/Mux'])
set_param([sys,'/','Subsystem5/Subsystem/Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[460,89,490,191])

add_block('built-in/Gain',[sys,'/','Subsystem5/Subsystem/Gain'])
set_param([sys,'/','Subsystem5/Subsystem/Gain'],...
		'hide name',0,...
		'Gain','vitesse_rotation',...
		'position',[90,232,115,258])

add_block('built-in/Demux',[sys,'/','Subsystem5/Subsystem/Demux'])
set_param([sys,'/','Subsystem5/Subsystem/Demux'],...
		'hide name',0,...
		'outputs','3',...
		'position',[105,58,150,172])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem/in_1'])
set_param([sys,'/','Subsystem5/Subsystem/in_1'],...
		'hide name',0,...
		'position',[55,105,75,125])

add_block('built-in/Demux',[sys,'/','Subsystem5/Subsystem/Demux1'])
set_param([sys,'/','Subsystem5/Subsystem/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[150,207,200,283])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem/in_2'])
set_param([sys,'/','Subsystem5/Subsystem/in_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[50,235,70,255])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem/Constant3'])
set_param([sys,'/','Subsystem5/Subsystem/Constant3'],...
		'hide name',0,...
		'Value','3*(Ir-Il)',...
		'position',[60,291,255,329])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem/Constant2'])
set_param([sys,'/','Subsystem5/Subsystem/Constant2'],...
		'hide name',0,...
		'Value','3*(Il-It)',...
		'position',[65,371,260,409])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum5'])
set_param([sys,'/','Subsystem5/Subsystem/Sum5'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[775,252,800,303])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/CALCUL DE L''ENERGIE MECANIQUE']])
set_param([sys,'/',['Subsystem5/Subsystem/CALCUL DE L''ENERGIE MECANIQUE']],...
		'Font Name','Arial',...
		'Font Size',16,...
		'position',[480,5,485,10])

add_block('built-in/Outport',[sys,'/','Subsystem5/Subsystem/Outport'])
set_param([sys,'/','Subsystem5/Subsystem/Outport'],...
		'position',[835,270,855,290])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/E. M'])
set_param([sys,'/','Subsystem5/Subsystem/E. M'],...
		'position',[895,265,900,270])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/energie',13,'cintique']])
set_param([sys,'/',['Subsystem5/Subsystem/energie',13,'cintique']],...
		'position',[660,145,665,150])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem5/Subsystem/MATLAB Fcn'])
set_param([sys,'/','Subsystem5/Subsystem/MATLAB Fcn'],...
		'MATLAB Fcn','cinetic(Asat,u)',...
		'Output Width','1',...
		'position',[560,123,620,157])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/energie potentielle',13,'du',13,'gradient']])
set_param([sys,'/',['Subsystem5/Subsystem/energie potentielle',13,'du',13,'gradient']],...
		'position',[635,320,640,325])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product1'])
set_param([sys,'/','Subsystem5/Subsystem/Product1'],...
		'position',[270,239,285,266])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product'])
set_param([sys,'/','Subsystem5/Subsystem/Product'],...
		'position',[360,244,385,291])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product2'])
set_param([sys,'/','Subsystem5/Subsystem/Product2'],...
		'position',[375,326,390,364])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum4'])
set_param([sys,'/','Subsystem5/Subsystem/Sum4'],...
		'hide name',0,...
		'position',[520,292,545,343])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product3'])
set_param([sys,'/','Subsystem5/Subsystem/Product3'],...
		'position',[425,323,455,412])

add_block('built-in/Gain',[sys,'/','Subsystem5/Subsystem/Gain1'])
set_param([sys,'/','Subsystem5/Subsystem/Gain1'],...
		'Gain','-1/2',...
		'position',[615,305,675,335])
add_line([sys,'/','Subsystem5/Subsystem'],[390,210;430,210;430,175;455,175])
add_line([sys,'/','Subsystem5/Subsystem'],[390,125;430,125;430,140;455,140])
add_line([sys,'/','Subsystem5/Subsystem'],[390,80;405,80;405,105;455,105])
add_line([sys,'/','Subsystem5/Subsystem'],[205,220;355,220])
add_line([sys,'/','Subsystem5/Subsystem'],[155,155;250,155;250,200;355,200])
add_line([sys,'/','Subsystem5/Subsystem'],[340,130;360,130])
add_line([sys,'/','Subsystem5/Subsystem'],[155,115;360,115])
add_line([sys,'/','Subsystem5/Subsystem'],[120,245;145,245])
add_line([sys,'/','Subsystem5/Subsystem'],[205,270;220,270;220,85;360,85])
add_line([sys,'/','Subsystem5/Subsystem'],[155,75;360,75])
add_line([sys,'/','Subsystem5/Subsystem'],[80,115;100,115])
add_line([sys,'/','Subsystem5/Subsystem'],[75,245;85,245])
add_line([sys,'/','Subsystem5/Subsystem'],[260,310;335,310;335,280;355,280])
add_line([sys,'/','Subsystem5/Subsystem'],[315,220;315,335;370,335])
add_line([sys,'/','Subsystem5/Subsystem'],[550,320;610,320])
add_line([sys,'/','Subsystem5/Subsystem'],[680,320;750,320;750,290;770,290])
add_line([sys,'/','Subsystem5/Subsystem'],[805,280;830,280])
add_line([sys,'/','Subsystem5/Subsystem'],[495,140;555,140])
add_line([sys,'/','Subsystem5/Subsystem'],[625,140;720,140;720,265;770,265])
add_line([sys,'/','Subsystem5/Subsystem'],[205,245;265,245])
add_line([sys,'/','Subsystem5/Subsystem'],[240,245;240,260;265,260])
add_line([sys,'/','Subsystem5/Subsystem'],[290,255;355,255])
add_line([sys,'/','Subsystem5/Subsystem'],[330,335;330,355;370,355])
add_line([sys,'/','Subsystem5/Subsystem'],[395,345;420,345])
add_line([sys,'/','Subsystem5/Subsystem'],[265,390;420,390])
add_line([sys,'/','Subsystem5/Subsystem'],[390,270;480,270;480,305;515,305])
add_line([sys,'/','Subsystem5/Subsystem'],[460,370;505,370;515,330])
set_param([sys,'/','Subsystem5/Subsystem'],...
		'Mask Display','ENERGIE')


%     Finished composite block 'Subsystem5/Subsystem'.

set_param([sys,'/','Subsystem5/Subsystem'],...
		'hide name',0,...
		'position',[165,302,270,338])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace6'])
set_param([sys,'/','Subsystem5/To Workspace6'],...
		'hide name',0,...
		'mat-name','cplx',...
		'buffer','points_trace',...
		'position',[155,72,205,88])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux3'])
set_param([sys,'/','Subsystem5/Demux3'],...
		'hide name',0,...
		'outputs','3',...
		'position',[75,68,115,152])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace12'])
set_param([sys,'/','Subsystem5/To Workspace12'],...
		'hide name',0,...
		'mat-name','cply',...
		'buffer','points_trace',...
		'position',[160,102,210,118])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace13'])
set_param([sys,'/','Subsystem5/To Workspace13'],...
		'hide name',0,...
		'mat-name','cplz',...
		'buffer','points_trace',...
		'position',[155,132,205,148])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux'])
set_param([sys,'/','Subsystem5/Demux'],...
		'hide name',0,...
		'outputs','[3,3]',...
		'position',[60,193,105,377])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux2'])
set_param([sys,'/','Subsystem5/Demux2'],...
		'hide name',0,...
		'outputs','3',...
		'position',[180,198,220,282])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace9'])
set_param([sys,'/','Subsystem5/To Workspace9'],...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[250,262,300,278])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace8'])
set_param([sys,'/','Subsystem5/To Workspace8'],...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[250,232,300,248])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace11'])
set_param([sys,'/','Subsystem5/To Workspace11'],...
		'hide name',0,...
		'mat-name','vitesses',...
		'buffer','2000',...
		'position',[180,157,230,173])

add_block('built-in/Inport',[sys,'/','Subsystem5/in_1'])
set_param([sys,'/','Subsystem5/in_1'],...
		'position',[15,100,35,120])

add_block('built-in/Inport',[sys,'/','Subsystem5/in_2'])
set_param([sys,'/','Subsystem5/in_2'],...
		'Port','2',...
		'position',[15,275,35,295])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace'])
set_param([sys,'/','Subsystem5/To Workspace'],...
		'mat-name','cpl_total',...
		'buffer','points_trace',...
		'position',[145,27,195,43])

add_block('built-in/Clock',[sys,'/','Subsystem5/Clock'])
set_param([sys,'/','Subsystem5/Clock'],...
		'position',[120,505,140,525])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace7'])
set_param([sys,'/','Subsystem5/To Workspace7'],...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[320,312,370,328])

add_block('built-in/Note',[sys,'/','Subsystem5/Angles en degrs'])
set_param([sys,'/','Subsystem5/Angles en degrs'],...
		'position',[315,340,320,345])


%     Subsystem  'Subsystem5/Sortie des angles en degrs'.

new_system([sys,'/','Subsystem5/Sortie des angles en degrs'])
set_param([sys,'/','Subsystem5/Sortie des angles en degrs'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem5/Sortie des angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem5/Sortie des angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Subsystem5/Sortie des angles en degrs/x'])
set_param([sys,'/','Subsystem5/Sortie des angles en degrs/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Subsystem5/Sortie des angles en degrs'],[90,65;125,65])
set_param([sys,'/','Subsystem5/Sortie des angles en degrs'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Subsystem5/Sortie des angles en degrs'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Subsystem5/Sortie des angles en degrs'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Subsystem5/Sortie des angles en degrs'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Subsystem5/Sortie des angles en degrs'],...
		'Mask Entries','1000\/-20\/20\/''y-/m--/c-./w:/g*/ro/b+''\/')


%     Finished composite block 'Subsystem5/Sortie des angles en degrs'.

set_param([sys,'/','Subsystem5/Sortie des angles en degrs'],...
		'BackGround',2,...
		'position',[395,342,490,388])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace10'])
set_param([sys,'/','Subsystem5/To Workspace10'],...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[250,202,300,218])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain7'])
set_param([sys,'/','Subsystem5/Gain7'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[325,172,360,198])


%     Subsystem  ['Subsystem5/Sortie des vitesses',13,'en degrs//s '].

new_system([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s ']])
set_param([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s ']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s /S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s /S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s /x']])
set_param([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s /x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s ']],[90,65;125,65])
set_param([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s ']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s ']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s ']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s ']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s ']],...
		'Mask Entries','1000\/-0.5\/0.5\/''y-/m--/c-./w:/g*/ro/b+''\/')


%     Finished composite block ['Subsystem5/Sortie des vitesses',13,'en degrs//s '].

set_param([sys,'/',['Subsystem5/Sortie des vitesses',13,'en degrs//s ']],...
		'BackGround',2,...
		'position',[405,162,500,208])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace5'])
set_param([sys,'/','Subsystem5/To Workspace5'],...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[360,507,410,523])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux1'])
set_param([sys,'/','Subsystem5/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[295,403,335,487])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace2'])
set_param([sys,'/','Subsystem5/To Workspace2'],...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[360,407,410,423])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace4'])
set_param([sys,'/','Subsystem5/To Workspace4'],...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[365,467,415,483])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace3'])
set_param([sys,'/','Subsystem5/To Workspace3'],...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','5000',...
		'position',[360,437,410,453])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain6'])
set_param([sys,'/','Subsystem5/Gain6'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[175,352,210,378])
add_line([sys,'/','Subsystem5'],[120,140;150,140])
add_line([sys,'/','Subsystem5'],[120,110;155,110])
add_line([sys,'/','Subsystem5'],[120,80;150,80])
add_line([sys,'/','Subsystem5'],[110,330;160,330])
add_line([sys,'/','Subsystem5'],[275,320;315,320])
add_line([sys,'/','Subsystem5'],[110,240;175,240])
add_line([sys,'/','Subsystem5'],[140,240;140,165;175,165])
add_line([sys,'/','Subsystem5'],[225,270;245,270])
add_line([sys,'/','Subsystem5'],[225,240;245,240])
add_line([sys,'/','Subsystem5'],[225,210;245,210])
add_line([sys,'/','Subsystem5'],[140,240;140,310;160,310])
add_line([sys,'/','Subsystem5'],[340,475;360,475])
add_line([sys,'/','Subsystem5'],[340,445;355,445])
add_line([sys,'/','Subsystem5'],[340,415;355,415])
add_line([sys,'/','Subsystem5'],[40,110;70,110])
add_line([sys,'/','Subsystem5'],[40,285;55,285])
add_line([sys,'/','Subsystem5'],[50,110;50,35;140,35])
add_line([sys,'/','Subsystem5'],[145,515;355,515])
add_line([sys,'/','Subsystem5'],[215,365;390,365])
add_line([sys,'/','Subsystem5'],[150,330;150,365;170,365])
add_line([sys,'/','Subsystem5'],[365,185;400,185])
add_line([sys,'/','Subsystem5'],[140,185;320,185])
add_line([sys,'/','Subsystem5'],[230,365;230,445;290,445])
set_param([sys,'/','Subsystem5'],...
		'Mask Display','SORTIES DES VARIABLES\n\nCOUPLE TOTAL\n\nENERGIE')


%     Finished composite block 'Subsystem5'.

set_param([sys,'/','Subsystem5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'position',[715,208,915,317])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=bleu\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[355,820,585,906])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\n\nmoments magntiques',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[355,750,580,811])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\n\nvitesses angulaires (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet)'');title(''Vitesses angulaires en /s'');grid;figure(gcf)')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[135,830,340,891])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\n\ndes angles',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);title(''''Angles mode fin en degrs'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[135,750,335,816])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir les courbes\ncouple \nperturbateurs (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_pert);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[600,825,795,886])

add_block('built-in/Note',[sys,'/',['SYNTHESE DE TOUTES LES POSSIBILITES DE COMMANDES ET DE CAS',13,'NANOSATELLITE CASAA-SAT (Rgulation petits angles et TMC )',13,'(  1 roue axe tangage + 2 magntocoupleurs axes roulis lacet )']])
set_param([sys,'/',['SYNTHESE DE TOUTES LES POSSIBILITES DE COMMANDES ET DE CAS',13,'NANOSATELLITE CASAA-SAT (Rgulation petits angles et TMC )',13,'(  1 roue axe tangage + 2 magntocoupleurs axes roulis lacet )']],...
		'ForeGround',3)
set_param([sys,'/',['SYNTHESE DE TOUTES LES POSSIBILITES DE COMMANDES ET DE CAS',13,'NANOSATELLITE CASAA-SAT (Rgulation petits angles et TMC )',13,'(  1 roue axe tangage + 2 magntocoupleurs axes roulis lacet )']],...
		'Font Name','Arial')
set_param([sys,'/',['SYNTHESE DE TOUTES LES POSSIBILITES DE COMMANDES ET DE CAS',13,'NANOSATELLITE CASAA-SAT (Rgulation petits angles et TMC )',13,'(  1 roue axe tangage + 2 magntocoupleurs axes roulis lacet )']],...
		'Font Weight','bold')
set_param([sys,'/',['SYNTHESE DE TOUTES LES POSSIBILITES DE COMMANDES ET DE CAS',13,'NANOSATELLITE CASAA-SAT (Rgulation petits angles et TMC )',13,'(  1 roue axe tangage + 2 magntocoupleurs axes roulis lacet )']],...
		'Font Size',18)
set_param([sys,'/',['SYNTHESE DE TOUTES LES POSSIBILITES DE COMMANDES ET DE CAS',13,'NANOSATELLITE CASAA-SAT (Rgulation petits angles et TMC )',13,'(  1 roue axe tangage + 2 magntocoupleurs axes roulis lacet )']],...
		'position',[600,45,605,50])

add_block('built-in/Note',[sys,'/',['SUIVRE L''ORDRE',13,' 1 ou 2 puis 3']])
set_param([sys,'/',['SUIVRE L''ORDRE',13,' 1 ou 2 puis 3']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Angle','italic',...
		'Font Size',22,...
		'position',[1070,165,1075,170])

add_block('built-in/Note',[sys,'/','puis -> simulation -> start'])
set_param([sys,'/','puis -> simulation -> start'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1070,650,1075,655])


%     Subsystem  'Extras4'.

new_system([sys,'/','Extras4'])
set_param([sys,'/','Extras4'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras4'],...
		'Mask Display','Sans dsaturation\n\n2\n\ndouble clic souris',...
		'Mask Dialogue','eval(''desat=0;reponse=0;'')')


%     Finished composite block 'Extras4'.

set_param([sys,'/','Extras4'],...
		'ForeGround',4,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[985,425,1175,521])

add_block('built-in/Note',[sys,'/',['CHOIX SIMULATION ',13,'AVEC OU SANS ',13,'DESATURATION']])
set_param([sys,'/',['CHOIX SIMULATION ',13,'AVEC OU SANS ',13,'DESATURATION']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1065,360,1070,365])


%     Subsystem  'Extras3'.

new_system([sys,'/','Extras3'])
set_param([sys,'/','Extras3'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras3'],...
		'Mask Display','Avec dsaturation\n\n1\n\ndouble clic souris',...
		'Mask Dialogue','eval(''desat=1,reponse=1'')')


%     Finished composite block 'Extras3'.

set_param([sys,'/','Extras3'],...
		'ForeGround',4,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[980,250,1170,361])

add_block('built-in/State-Space',[sys,'/','State-space'])
set_param([sys,'/','State-space'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'A','A_SIM(Asat,K_SAT,H_SAT,L_SAT,Q_SAT,vitesseroue)',...
		'B','B_SIM(Asat,K_SAT,H_SAT,L_SAT,Q_SAT)',...
		'C','eye(6)',...
		'D','zeros(6,3)')
set_param([sys,'/','State-space'],...
		'X0','etat_init_tmc',...
		'Mask Display','MODELE\nSATELLITE',...
		'position',[745,358,860,412])

add_block('built-in/Note',[sys,'/','1 + 3 + 4 : fonctionnement parfait'])
set_param([sys,'/','1 + 3 + 4 : fonctionnement parfait'],...
		'position',[625,570,630,575])

add_block('built-in/Note',[sys,'/','1 + 2 + 3 + 4 + 5 : fonctionnement parfait'])
set_param([sys,'/','1 + 2 + 3 + 4 + 5 : fonctionnement parfait'],...
		'position',[655,595,660,600])

add_block('built-in/Note',[sys,'/',[' 3 + 4 + 5  : fonctionnement parfait  ',13,'']])
set_param([sys,'/',[' 3 + 4 + 5  : fonctionnement parfait  ',13,'']],...
		'position',[640,615,645,620])

add_block('built-in/Note',[sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']])
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'ForeGround',4)
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'Font Name','Arial')
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'Font Weight','bold')
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'Font Size',14)
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'position',[620,675,625,680])


%     Subsystem  'Subsystem4'.

new_system([sys,'/','Subsystem4'])
set_param([sys,'/','Subsystem4'],'Location',[216,231,1093,687])

add_block('built-in/Inport',[sys,'/','Subsystem4/in_1'])
set_param([sys,'/','Subsystem4/in_1'],...
		'position',[145,185,165,205])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem4/MATLAB Fcn'])
set_param([sys,'/','Subsystem4/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','condpert(u)',...
		'Output Width','7',...
		'position',[195,178,255,212])

add_block('built-in/To Workspace',[sys,'/','Subsystem4/To Workspace'])
set_param([sys,'/','Subsystem4/To Workspace'],...
		'hide name',0,...
		'mat-name','etat_init',...
		'buffer','1',...
		'position',[315,180,385,210])

add_block('built-in/Note',[sys,'/','Subsystem4/vitesses et quaternion'])
set_param([sys,'/','Subsystem4/vitesses et quaternion'],...
		'position',[360,150,365,155])

add_block('built-in/Note',[sys,'/','Subsystem4/Variable modfin2pert'])
set_param([sys,'/','Subsystem4/Variable modfin2pert'],...
		'position',[600,250,605,255])

add_block('built-in/Note',[sys,'/','Subsystem4/Temps final'])
set_param([sys,'/','Subsystem4/Temps final'],...
		'position',[340,350,345,355])

add_block('built-in/To Workspace',[sys,'/','Subsystem4/To Workspace1'])
set_param([sys,'/','Subsystem4/To Workspace1'],...
		'hide name',0,...
		'mat-name','temps_init_pert',...
		'buffer','1',...
		'position',[285,314,405,346])

add_block('built-in/Clock',[sys,'/','Subsystem4/Clock'])
set_param([sys,'/','Subsystem4/Clock'],...
		'hide name',0,...
		'position',[130,311,170,349])

add_block('built-in/Note',[sys,'/',['Subsystem4/Variable modfin2pert',13,'']])
set_param([sys,'/',['Subsystem4/Variable modfin2pert',13,'']],...
		'position',[610,280,615,285])

add_block('built-in/Note',[sys,'/',['Subsystem4/TRANSMISSION DES VALEURS FINALES',13,'AU REGIME LIBRE AVEC PERTURBATIONS']])
set_param([sys,'/',['Subsystem4/TRANSMISSION DES VALEURS FINALES',13,'AU REGIME LIBRE AVEC PERTURBATIONS']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[475,60,480,65])

add_block('built-in/To File',[sys,'/','Subsystem4/To File'])
set_param([sys,'/','Subsystem4/To File'],...
		'hide name',0,...
		'File name','init_lib.mat',...
		'Matrix name','modfin2pert',...
		'position',[545,232,685,278])

add_block('built-in/Mux',[sys,'/','Subsystem4/Mux'])
set_param([sys,'/','Subsystem4/Mux'],...
		'inputs','[7 1]',...
		'position',[455,209,490,296])
add_line([sys,'/','Subsystem4'],[170,195;190,195])
add_line([sys,'/','Subsystem4'],[260,195;310,195])
add_line([sys,'/','Subsystem4'],[175,330;280,330])
add_line([sys,'/','Subsystem4'],[280,195;280,230;450,230])
add_line([sys,'/','Subsystem4'],[240,330;240,275;450,275])
add_line([sys,'/','Subsystem4'],[495,255;540,255])
set_param([sys,'/','Subsystem4'],...
		'Mask Display','TRANSMISSION\nCONDITIONS FINALES')


%     Finished composite block 'Subsystem4'.

set_param([sys,'/','Subsystem4'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[685,496,860,554])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir les courbes\n\nvitesse roue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vitesseroue*30/pi);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[600,750,790,811])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Voir les courbes\n\ncouple roue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue*30/pi);grid;figure(gcf)'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[800,750,990,811])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','INITIALISATION\n3\npar double clic souris\nlance dat_fin.m',...
		'Mask Dialogue','eval(''dat_fin'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[980,530,1180,631])

add_block('built-in/Note',[sys,'/',['Allez consulter ',13,'l''espace Matlab']])
set_param([sys,'/',['Allez consulter ',13,'l''espace Matlab']],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[915,830,920,835])
add_line(sys,[735,385;740,385])
add_line(sys,[660,385;690,385])
add_line(sys,[450,425;505,425])
add_line(sys,[540,265;605,265])
add_line(sys,[675,385;675,235;710,235])
add_line(sys,[450,265;495,265])
add_line(sys,[865,385;890,385;890,340;695,340;695,290;710,290])
add_line(sys,[445,505;505,505])
add_line(sys,[445,555;495,555;495,610;55,610;55,305;90,305])
add_line(sys,[890,385;890,650;30,650;30,425;90,425])
add_line(sys,[550,505;605,505])
add_line(sys,[550,425;605,425])
add_line(sys,[450,345;505,345])
add_line(sys,[550,345;605,345])
add_line(sys,[30,530;85,530])
add_line(sys,[890,450;870,450])
add_line(sys,[890,525;865,525])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
